# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/monitoring/monitoring.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from stellarstation.api.v1.antenna import antenna_pb2 as stellarstation_dot_api_dot_v1_dot_antenna_dot_antenna__pb2
from stellarstation.api.v1.common import common_pb2 as stellarstation_dot_api_dot_v1_dot_common_dot_common__pb2
from stellarstation.api.v1.radio import radio_pb2 as stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/monitoring/monitoring.proto',
  package='stellarstation.api.v1.monitoring',
  syntax='proto3',
  serialized_options=_b('\n$com.stellarstation.api.v1.monitoringB\017MonitoringProtoP\001Z=github.com/infostellarinc/go-stellarstation/api/v1/monitoring'),
  serialized_pb=_b('\n1stellarstation/api/v1/monitoring/monitoring.proto\x12 stellarstation.api.v1.monitoring\x1a+stellarstation/api/v1/antenna/antenna.proto\x1a)stellarstation/api/v1/common/common.proto\x1a\'stellarstation/api/v1/radio/radio.proto\"\xfe\x01\n\x18TransmitterConfiguration\x12;\n\nmodulation\x18\x01 \x01(\x0e\x32\'.stellarstation.api.v1.radio.Modulation\x12\x1a\n\x12is_carrier_enabled\x18\x02 \x01(\x08\x12\x0f\n\x07\x62itrate\x18\x03 \x01(\x04\x12<\n\x0bline_coding\x18\x04 \x01(\x0e\x32\'.stellarstation.api.v1.radio.LineCoding\x12\x1b\n\x13\x66ilter_bandwidth_hz\x18\x05 \x01(\x04\x12\x1d\n\x15sampling_frequency_hz\x18\x06 \x01(\x04\"\xee\x03\n\x15ReceiverConfiguration\x12;\n\nmodulation\x18\x01 \x01(\x0e\x32\'.stellarstation.api.v1.radio.Modulation\x12\x14\n\x0c\x62\x61ndwidth_hz\x18\x02 \x01(\x04\x12\x1d\n\x15sampling_frequency_hz\x18\x03 \x01(\x04\x12\x0f\n\x07\x62itrate\x18\x04 \x01(\x04\x12<\n\x0bline_coding\x18\x05 \x01(\x0e\x32\'.stellarstation.api.v1.radio.LineCoding\x12@\n\x14synchronization_word\x18\x06 \x01(\x0b\x32\".stellarstation.api.v1.common.Bits\x12*\n\"is_convolutional_code_descrambling\x18\x07 \x01(\x08\x12&\n\x1eis_convolutional_code_decoding\x18\x08 \x01(\x08\x12&\n\x1eis_convolutional_code_inverted\x18\t \x01(\x08\x12\x1f\n\x17is_reed_solomon_enabled\x18\n \x01(\x08\x12\x12\n\nframe_size\x18\x0b \x01(\r\x12!\n\x19is_frame_checking_enabled\x18\x0c \x01(\x08\"\xfe\x01\n\x1aGroundStationConfiguration\x12O\n\x0btransmitter\x18\x01 \x01(\x0b\x32:.stellarstation.api.v1.monitoring.TransmitterConfiguration\x12I\n\x08receiver\x18\x02 \x01(\x0b\x32\x37.stellarstation.api.v1.monitoring.ReceiverConfiguration\x12\x44\n\x07\x61ntenna\x18\x03 \x01(\x0b\x32\x33.stellarstation.api.v1.antenna.AntennaConfiguration\"J\n\x10TransmitterState\x12\x1b\n\x13\x63\x65nter_frequency_hz\x18\x01 \x01(\x04\x12\x19\n\x11\x63\x61rrier_level_dbm\x18\x02 \x01(\x01\"\xc8\x01\n\x11ReedSolomonStatus\x12J\n\x06status\x18\x01 \x01(\x0e\x32:.stellarstation.api.v1.monitoring.ReedSolomonStatus.Status\x12\x1d\n\x15num_corrected_signals\x18\x02 \x01(\r\"H\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x14\n\x10INTERLEAVE_ERROR\x10\x01\x12 \n\x1c\x43ORRECTION_CAPACITY_EXCEEDED\x10\x02\"\xa3\x03\n\rReceiverState\x12\x1b\n\x13\x63\x65nter_frequency_hz\x18\x01 \x01(\x04\x12\x19\n\x11\x63\x61rrier_level_dbm\x18\x02 \x01(\x01\x12\x17\n\x0fis_phase_locked\x18\x03 \x01(\x08\x12\"\n\x1ais_bit_synchronizer_locked\x18\x04 \x01(\x08\x12\x16\n\x0enormalized_snr\x18\x05 \x01(\x01\x12$\n\x1cis_frame_synchronizer_locked\x18\x06 \x01(\x08\x12`\n\x1b\x63onvolutional_coding_status\x18\x07 \x01(\x0e\x32;.stellarstation.api.v1.monitoring.ConvolutionalCodingStatus\x12+\n#convolutional_coding_bit_error_rate\x18\x08 \x01(\x01\x12P\n\x13reed_solomon_status\x18\t \x01(\x0b\x32\x33.stellarstation.api.v1.monitoring.ReedSolomonStatus\"\x94\x02\n\x0c\x41ntennaState\x12\x45\n\x07\x61zimuth\x18\x01 \x01(\x0b\x32\x34.stellarstation.api.v1.monitoring.AntennaState.Angle\x12G\n\televation\x18\x02 \x01(\x0b\x32\x34.stellarstation.api.v1.monitoring.AntennaState.Angle\x12H\n\x0cpolarization\x18\x03 \x01(\x0e\x32\x32.stellarstation.api.v1.antenna.AntennaPolarization\x1a*\n\x05\x41ngle\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\x01\x12\x10\n\x08measured\x18\x02 \x01(\x01\"\xe1\x01\n\x12GroundStationState\x12G\n\x0btransmitter\x18\x01 \x01(\x0b\x32\x32.stellarstation.api.v1.monitoring.TransmitterState\x12\x41\n\x08receiver\x18\x02 \x01(\x0b\x32/.stellarstation.api.v1.monitoring.ReceiverState\x12?\n\x07\x61ntenna\x18\x03 \x01(\x0b\x32..stellarstation.api.v1.monitoring.AntennaState*Q\n\x19\x43onvolutionalCodingStatus\x12\x0c\n\x08UNLOCKED\x10\x00\x12\x0c\n\x08I_LOCKED\x10\x01\x12\x0c\n\x08Q_LOCKED\x10\x02\x12\n\n\x06LOCKED\x10\x03\x42x\n$com.stellarstation.api.v1.monitoringB\x0fMonitoringProtoP\x01Z=github.com/infostellarinc/go-stellarstation/api/v1/monitoringb\x06proto3')
  ,
  dependencies=[stellarstation_dot_api_dot_v1_dot_antenna_dot_antenna__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_common_dot_common__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2.DESCRIPTOR,])

_CONVOLUTIONALCODINGSTATUS = _descriptor.EnumDescriptor(
  name='ConvolutionalCodingStatus',
  full_name='stellarstation.api.v1.monitoring.ConvolutionalCodingStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNLOCKED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='I_LOCKED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Q_LOCKED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCKED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2435,
  serialized_end=2516,
)
_sym_db.RegisterEnumDescriptor(_CONVOLUTIONALCODINGSTATUS)

ConvolutionalCodingStatus = enum_type_wrapper.EnumTypeWrapper(_CONVOLUTIONALCODINGSTATUS)
UNLOCKED = 0
I_LOCKED = 1
Q_LOCKED = 2
LOCKED = 3


_REEDSOLOMONSTATUS_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='stellarstation.api.v1.monitoring.ReedSolomonStatus.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERLEAVE_ERROR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CORRECTION_CAPACITY_EXCEEDED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1432,
  serialized_end=1504,
)
_sym_db.RegisterEnumDescriptor(_REEDSOLOMONSTATUS_STATUS)


_TRANSMITTERCONFIGURATION = _descriptor.Descriptor(
  name='TransmitterConfiguration',
  full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modulation', full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration.modulation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_carrier_enabled', full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration.is_carrier_enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bitrate', full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration.bitrate', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_coding', full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration.line_coding', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_bandwidth_hz', full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration.filter_bandwidth_hz', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampling_frequency_hz', full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration.sampling_frequency_hz', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=471,
)


_RECEIVERCONFIGURATION = _descriptor.Descriptor(
  name='ReceiverConfiguration',
  full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modulation', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.modulation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bandwidth_hz', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.bandwidth_hz', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampling_frequency_hz', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.sampling_frequency_hz', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bitrate', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.bitrate', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_coding', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.line_coding', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='synchronization_word', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.synchronization_word', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_convolutional_code_descrambling', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.is_convolutional_code_descrambling', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_convolutional_code_decoding', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.is_convolutional_code_decoding', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_convolutional_code_inverted', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.is_convolutional_code_inverted', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_reed_solomon_enabled', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.is_reed_solomon_enabled', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_size', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.frame_size', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_frame_checking_enabled', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.is_frame_checking_enabled', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=968,
)


_GROUNDSTATIONCONFIGURATION = _descriptor.Descriptor(
  name='GroundStationConfiguration',
  full_name='stellarstation.api.v1.monitoring.GroundStationConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transmitter', full_name='stellarstation.api.v1.monitoring.GroundStationConfiguration.transmitter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receiver', full_name='stellarstation.api.v1.monitoring.GroundStationConfiguration.receiver', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='antenna', full_name='stellarstation.api.v1.monitoring.GroundStationConfiguration.antenna', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1225,
)


_TRANSMITTERSTATE = _descriptor.Descriptor(
  name='TransmitterState',
  full_name='stellarstation.api.v1.monitoring.TransmitterState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='center_frequency_hz', full_name='stellarstation.api.v1.monitoring.TransmitterState.center_frequency_hz', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='carrier_level_dbm', full_name='stellarstation.api.v1.monitoring.TransmitterState.carrier_level_dbm', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1227,
  serialized_end=1301,
)


_REEDSOLOMONSTATUS = _descriptor.Descriptor(
  name='ReedSolomonStatus',
  full_name='stellarstation.api.v1.monitoring.ReedSolomonStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='stellarstation.api.v1.monitoring.ReedSolomonStatus.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_corrected_signals', full_name='stellarstation.api.v1.monitoring.ReedSolomonStatus.num_corrected_signals', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REEDSOLOMONSTATUS_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1304,
  serialized_end=1504,
)


_RECEIVERSTATE = _descriptor.Descriptor(
  name='ReceiverState',
  full_name='stellarstation.api.v1.monitoring.ReceiverState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='center_frequency_hz', full_name='stellarstation.api.v1.monitoring.ReceiverState.center_frequency_hz', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='carrier_level_dbm', full_name='stellarstation.api.v1.monitoring.ReceiverState.carrier_level_dbm', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_phase_locked', full_name='stellarstation.api.v1.monitoring.ReceiverState.is_phase_locked', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_bit_synchronizer_locked', full_name='stellarstation.api.v1.monitoring.ReceiverState.is_bit_synchronizer_locked', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='normalized_snr', full_name='stellarstation.api.v1.monitoring.ReceiverState.normalized_snr', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_frame_synchronizer_locked', full_name='stellarstation.api.v1.monitoring.ReceiverState.is_frame_synchronizer_locked', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='convolutional_coding_status', full_name='stellarstation.api.v1.monitoring.ReceiverState.convolutional_coding_status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='convolutional_coding_bit_error_rate', full_name='stellarstation.api.v1.monitoring.ReceiverState.convolutional_coding_bit_error_rate', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reed_solomon_status', full_name='stellarstation.api.v1.monitoring.ReceiverState.reed_solomon_status', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1507,
  serialized_end=1926,
)


_ANTENNASTATE_ANGLE = _descriptor.Descriptor(
  name='Angle',
  full_name='stellarstation.api.v1.monitoring.AntennaState.Angle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='stellarstation.api.v1.monitoring.AntennaState.Angle.command', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='measured', full_name='stellarstation.api.v1.monitoring.AntennaState.Angle.measured', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2163,
  serialized_end=2205,
)

_ANTENNASTATE = _descriptor.Descriptor(
  name='AntennaState',
  full_name='stellarstation.api.v1.monitoring.AntennaState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='azimuth', full_name='stellarstation.api.v1.monitoring.AntennaState.azimuth', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elevation', full_name='stellarstation.api.v1.monitoring.AntennaState.elevation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='polarization', full_name='stellarstation.api.v1.monitoring.AntennaState.polarization', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ANTENNASTATE_ANGLE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1929,
  serialized_end=2205,
)


_GROUNDSTATIONSTATE = _descriptor.Descriptor(
  name='GroundStationState',
  full_name='stellarstation.api.v1.monitoring.GroundStationState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transmitter', full_name='stellarstation.api.v1.monitoring.GroundStationState.transmitter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receiver', full_name='stellarstation.api.v1.monitoring.GroundStationState.receiver', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='antenna', full_name='stellarstation.api.v1.monitoring.GroundStationState.antenna', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2208,
  serialized_end=2433,
)

_TRANSMITTERCONFIGURATION.fields_by_name['modulation'].enum_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._MODULATION
_TRANSMITTERCONFIGURATION.fields_by_name['line_coding'].enum_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._LINECODING
_RECEIVERCONFIGURATION.fields_by_name['modulation'].enum_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._MODULATION
_RECEIVERCONFIGURATION.fields_by_name['line_coding'].enum_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._LINECODING
_RECEIVERCONFIGURATION.fields_by_name['synchronization_word'].message_type = stellarstation_dot_api_dot_v1_dot_common_dot_common__pb2._BITS
_GROUNDSTATIONCONFIGURATION.fields_by_name['transmitter'].message_type = _TRANSMITTERCONFIGURATION
_GROUNDSTATIONCONFIGURATION.fields_by_name['receiver'].message_type = _RECEIVERCONFIGURATION
_GROUNDSTATIONCONFIGURATION.fields_by_name['antenna'].message_type = stellarstation_dot_api_dot_v1_dot_antenna_dot_antenna__pb2._ANTENNACONFIGURATION
_REEDSOLOMONSTATUS.fields_by_name['status'].enum_type = _REEDSOLOMONSTATUS_STATUS
_REEDSOLOMONSTATUS_STATUS.containing_type = _REEDSOLOMONSTATUS
_RECEIVERSTATE.fields_by_name['convolutional_coding_status'].enum_type = _CONVOLUTIONALCODINGSTATUS
_RECEIVERSTATE.fields_by_name['reed_solomon_status'].message_type = _REEDSOLOMONSTATUS
_ANTENNASTATE_ANGLE.containing_type = _ANTENNASTATE
_ANTENNASTATE.fields_by_name['azimuth'].message_type = _ANTENNASTATE_ANGLE
_ANTENNASTATE.fields_by_name['elevation'].message_type = _ANTENNASTATE_ANGLE
_ANTENNASTATE.fields_by_name['polarization'].enum_type = stellarstation_dot_api_dot_v1_dot_antenna_dot_antenna__pb2._ANTENNAPOLARIZATION
_GROUNDSTATIONSTATE.fields_by_name['transmitter'].message_type = _TRANSMITTERSTATE
_GROUNDSTATIONSTATE.fields_by_name['receiver'].message_type = _RECEIVERSTATE
_GROUNDSTATIONSTATE.fields_by_name['antenna'].message_type = _ANTENNASTATE
DESCRIPTOR.message_types_by_name['TransmitterConfiguration'] = _TRANSMITTERCONFIGURATION
DESCRIPTOR.message_types_by_name['ReceiverConfiguration'] = _RECEIVERCONFIGURATION
DESCRIPTOR.message_types_by_name['GroundStationConfiguration'] = _GROUNDSTATIONCONFIGURATION
DESCRIPTOR.message_types_by_name['TransmitterState'] = _TRANSMITTERSTATE
DESCRIPTOR.message_types_by_name['ReedSolomonStatus'] = _REEDSOLOMONSTATUS
DESCRIPTOR.message_types_by_name['ReceiverState'] = _RECEIVERSTATE
DESCRIPTOR.message_types_by_name['AntennaState'] = _ANTENNASTATE
DESCRIPTOR.message_types_by_name['GroundStationState'] = _GROUNDSTATIONSTATE
DESCRIPTOR.enum_types_by_name['ConvolutionalCodingStatus'] = _CONVOLUTIONALCODINGSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TransmitterConfiguration = _reflection.GeneratedProtocolMessageType('TransmitterConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _TRANSMITTERCONFIGURATION,
  __module__ = 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.TransmitterConfiguration)
  ))
_sym_db.RegisterMessage(TransmitterConfiguration)

ReceiverConfiguration = _reflection.GeneratedProtocolMessageType('ReceiverConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _RECEIVERCONFIGURATION,
  __module__ = 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.ReceiverConfiguration)
  ))
_sym_db.RegisterMessage(ReceiverConfiguration)

GroundStationConfiguration = _reflection.GeneratedProtocolMessageType('GroundStationConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _GROUNDSTATIONCONFIGURATION,
  __module__ = 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.GroundStationConfiguration)
  ))
_sym_db.RegisterMessage(GroundStationConfiguration)

TransmitterState = _reflection.GeneratedProtocolMessageType('TransmitterState', (_message.Message,), dict(
  DESCRIPTOR = _TRANSMITTERSTATE,
  __module__ = 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.TransmitterState)
  ))
_sym_db.RegisterMessage(TransmitterState)

ReedSolomonStatus = _reflection.GeneratedProtocolMessageType('ReedSolomonStatus', (_message.Message,), dict(
  DESCRIPTOR = _REEDSOLOMONSTATUS,
  __module__ = 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.ReedSolomonStatus)
  ))
_sym_db.RegisterMessage(ReedSolomonStatus)

ReceiverState = _reflection.GeneratedProtocolMessageType('ReceiverState', (_message.Message,), dict(
  DESCRIPTOR = _RECEIVERSTATE,
  __module__ = 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.ReceiverState)
  ))
_sym_db.RegisterMessage(ReceiverState)

AntennaState = _reflection.GeneratedProtocolMessageType('AntennaState', (_message.Message,), dict(

  Angle = _reflection.GeneratedProtocolMessageType('Angle', (_message.Message,), dict(
    DESCRIPTOR = _ANTENNASTATE_ANGLE,
    __module__ = 'stellarstation.api.v1.monitoring.monitoring_pb2'
    # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.AntennaState.Angle)
    ))
  ,
  DESCRIPTOR = _ANTENNASTATE,
  __module__ = 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.AntennaState)
  ))
_sym_db.RegisterMessage(AntennaState)
_sym_db.RegisterMessage(AntennaState.Angle)

GroundStationState = _reflection.GeneratedProtocolMessageType('GroundStationState', (_message.Message,), dict(
  DESCRIPTOR = _GROUNDSTATIONSTATE,
  __module__ = 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.GroundStationState)
  ))
_sym_db.RegisterMessage(GroundStationState)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
